# [Meshagent](https://www.meshagent.com)

## MeshAgent Otel

The ``meshagent.otel`` package is a streamlined way to enable otel in your meshagent projects.

Check out the [CLI Quickstart](https://docs.meshagent.com/cli/getting_started) for more details.

---
### Learn more about MeshAgent on our website or check out the docs for additional examples!

**Website**: [www.meshagent.com](https://www.meshagent.com/)

**Documentation**: [docs.meshagent.com](https://docs.meshagent.com/)

---
